Class: ActiveRecord::Base
- Inherits:
-
Object
- Object
- ActiveRecord::Base
- Defined in:
- lib/generators/silmarails/install/files/spec/support/silmarails.rb
Instance Method Summary collapse
-
#test_attributes ⇒ Object
this method returns the attributes to use on controller tests.
Instance Method Details
#test_attributes ⇒ Object
this method returns the attributes to use on controller tests
4 5 6 7 8 |
# File 'lib/generators/silmarails/install/files/spec/support/silmarails.rb', line 4 def test_attributes attributes.delete_if do |key, value| ["id", "created_at", "updated_at"].include? key end end |